@@ -28,8 +28,13 @@
 #' the function returns a subset of \code{"/dev/tty[...]"}, which is also present in the 
 #' \code{"../pnp0/.."} folder.
 #' 
-#' On MacOs the installed interfaces are marked by "\code{tty.<name>}", with a unique 
+#' On MacOs the installed interfaces are marked by "\code{tty.<name>}" or "\code{cu.<name>}", with a unique 
 #' name after the dot, which makes it easier to search for installed devices.
+#' Here a \code{tty} device is a modem which waits for a DCD (Data Carrier Detect)
+#' signal to receive data. The device is blocked as long such a signal is 
+#' not detected. The corresponding \code{cu} device manages the out going communication
+#' for historical reasons. However a \code{cu} port is not blocked and should be used
+#' in favour on MacOS.
 #' 
 #' Subsequently, the user must know which interface is present and which isn't. AND the user
 #' must have at least reading permissions in the corresponding folders. So in the end,
@@ -52,13 +57,13 @@ listPorts <- function()
     ser_devs <- tclvalue( .Tcl( paste("registry values",regpath) ) )
     ser_devs <- strsplit( ser_devs, " ")[[1]]
     sList <- sapply(ser_devs,function(val) tclvalue(.Tcl(paste("registry get",regpath,val))))
-    attr(sList,"names")<-NULL
+    attr(sList,"names") <- NULL
   }
   
   if(.Platform$OS.type == "unix") # the R's platform is more general
   {
     # get all possible tty's
-    sList <- dir("/dev/",pattern = "tty[0SU.'ACM''USB']")
+    sList <- dir("/dev/",pattern = "tty[0SU.'ACM''USB''XRUSB''AMA''rfcomm''AP']")
     
     if(tk_platform != "macosx") # any other unix
     {
@@ -81,6 +86,10 @@ listPorts <- function()
       if(sum(p %in% sList) > 0)
         sList <- sList[sList %in% p]
     }
+    if(tk_platform == "macosx")
+    {
+      sList <- dir("/dev/",pattern = "cu[0SU.'ACM''USB''XRUSB''AMA''rfcomm''AP''Port']")
+    }
     message("Hint: On unix-systems the port list might be incomplete!")
   }
   
